@@ -40,12 +40,13 @@
 #include <KSharedConfig>
 #include <KConfigGroup>
 #include <KHelpClient>
-#include <kio_version.h>
+#include <KHelpMenu>
+#include <KSaneWidget>
 
 #include <skanlite_debug.h>
 
 #include <errno.h>
-
+using namespace KSaneIface;
 Skanlite::Skanlite(const QString &device, QWidget *parent)
     : QDialog(parent)
     , m_dbusInterface(this)
@@ -53,13 +54,19 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     QDialogButtonBox *dlgButtonBoxBottom = new QDialogButtonBox(this);
-    dlgButtonBoxBottom->setStandardButtons(QDialogButtonBox::Help | QDialogButtonBox::Close);
-    QPushButton *btnAbout = dlgButtonBoxBottom->addButton(i18n("About"), QDialogButtonBox::ButtonRole::HelpRole);
-    btnAbout->setIcon(QIcon::fromTheme(QStringLiteral("skanlite")));
+    dlgButtonBoxBottom->setStandardButtons(QDialogButtonBox::Help);
+    dlgButtonBoxBottom->button(QDialogButtonBox::Help)->setAutoDefault(false);
+
+    KHelpMenu *helpMenu = new KHelpMenu(this, KAboutData::applicationData(), false);
+    dlgButtonBoxBottom->button(QDialogButtonBox::Help)->setMenu(helpMenu->menu());
+
+    QPushButton *btnConfigure = dlgButtonBoxBottom->addButton(i18n("Configure..."), QDialogButtonBox::ButtonRole::ResetRole);
+    btnConfigure->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
+    btnConfigure->setAutoDefault(false);
+
     QPushButton *btnReselectDevice = dlgButtonBoxBottom->addButton(i18n("Reselect scanner device"), QDialogButtonBox::ButtonRole::ActionRole);
     btnReselectDevice->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
-    QPushButton *btnSettings = dlgButtonBoxBottom->addButton(i18n("Settings"), QDialogButtonBox::ButtonRole::ActionRole);
-    btnSettings->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
+    btnReselectDevice->setAutoDefault(false);
 
     m_firstImage = true;
 
@@ -87,7 +94,7 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
     mainLayout->addWidget(dlgButtonBoxBottom);
 
     // read the size here...
-    KConfigGroup window(KSharedConfig::openConfig(), "Window");
+    KConfigGroup window(KSharedConfig::openStateConfig(), "Window");
     QSize rect = window.readEntry("Geometry", QSize(740, 400));
     resize(rect);
 
@@ -96,7 +103,7 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
     QString deviceVendor;
     QString deviceModel;
     if (device.isEmpty()) {
-        KConfigGroup general(KSharedConfig::openConfig(), QStringLiteral("General"));
+        KConfigGroup general(KSharedConfig::openStateConfig(), QStringLiteral("General"));
         deviceName = general.readEntry(QStringLiteral("deviceName"));
         deviceVendor = general.readEntry(QStringLiteral("deviceVendor"));
         deviceModel = general.readEntry(QStringLiteral("deviceModel"));
@@ -108,9 +115,8 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
     connect(this, &QDialog::finished, this, &Skanlite::saveWindowSize);
     connect(this, &QDialog::finished, this, &Skanlite::saveScannerDevice);
     connect(this, &QDialog::finished, this, &Skanlite::saveScannerOptions);
-    connect(btnSettings, &QPushButton::clicked, this, &Skanlite::showSettingsDialog);
+    connect(btnConfigure, &QPushButton::clicked, this, &Skanlite::showSettingsDialog);
     connect(btnReselectDevice, &QPushButton::clicked, this, &Skanlite::reselectScannerDevice);
-    connect(btnAbout, &QPushButton::clicked, this, &Skanlite::showAboutDialog);
     connect(dlgButtonBoxBottom, &QDialogButtonBox::helpRequested, this, &Skanlite::showHelp);
 
     //
@@ -267,14 +273,14 @@ void Skanlite::closeEvent(QCloseEvent *event)
 
 void Skanlite::saveWindowSize()
 {
-    KConfigGroup window(KSharedConfig::openConfig(), "Window");
+    KConfigGroup window(KSharedConfig::openStateConfig(), "Window");
     window.writeEntry("Geometry", size());
     window.sync();
 }
 
 void Skanlite::saveScannerDevice()
 {
-    KConfigGroup general(KSharedConfig::openConfig(), "General");
+    KConfigGroup general(KSharedConfig::openStateConfig(), "General");
     general.writeEntry(QStringLiteral("deviceName"), m_deviceName);
     general.writeEntry(QStringLiteral("deviceModel"), m_deviceModel);
     general.writeEntry(QStringLiteral("deviceVendor"), m_deviceVendor);
@@ -547,6 +553,7 @@ void Skanlite::saveImage()
 
     SkanliteImageSaver *imageSaver = new SkanliteImageSaver(this);
     connect(imageSaver, &SkanliteImageSaver::imageSaved, this, &Skanlite::imageSaved);
+    connect(imageSaver, &SkanliteImageSaver::finished, &SkanliteImageSaver::deleteLater);
 
     imageSaver->saveQImage(fileUrl, localName, m_img, fileFormat, quality);
 
@@ -621,21 +628,11 @@ void Skanlite::imageSaved(const QUrl &fileUrl, const QString &localName, bool su
     m_ksanew->setFocus();
     m_saveUpdateTimer.stop();
     m_saveProgressBar->setVisible(false);
-
-    SkanliteImageSaver *imageSaver = qobject_cast<SkanliteImageSaver *>(sender());
-    if (imageSaver) {
-        imageSaver->deleteLater();
-    }
-}
-
-void Skanlite::showAboutDialog(void)
-{
-    KAboutApplicationDialog(KAboutData::applicationData()).exec();
 }
 
 void writeScannerOptions(const QString &groupName, const QMap <QString, QString> &opts)
 {
-    KConfigGroup options(KSharedConfig::openConfig(), groupName);
+    KConfigGroup options(KSharedConfig::openStateConfig(), groupName);
     QMap<QString, QString>::const_iterator it = opts.constBegin();
     while (it != opts.constEnd()) {
         options.writeEntry(it.key(), it.value());
@@ -646,7 +643,7 @@ void writeScannerOptions(const QString &groupName, const QMap <QString, QString>
 
 void readScannerOptions(const QString &groupName, QMap <QString, QString> &opts)
 {
-    KConfigGroup scannerOptions(KSharedConfig::openConfig(), groupName);
+    KConfigGroup scannerOptions(KSharedConfig::openStateConfig(), groupName);
     opts = scannerOptions.entryMap();
 }
 
@@ -660,7 +657,7 @@ void Skanlite::saveScannerOptions()
     }
 
     if (!m_deviceName.isEmpty()) {
-        KConfigGroup options(KSharedConfig::openConfig(), QStringLiteral("Options For %1").arg(m_deviceName));
+        KConfigGroup options(KSharedConfig::openStateConfig(), QStringLiteral("Options For %1").arg(m_deviceName));
         QMap <QString, QString> opts;
         m_ksanew->getOptVals(opts);
         writeScannerOptions(QStringLiteral("Options For %1").arg(m_deviceName), opts);
